Classes
=======

Below find all the documentation provided for the algorithms implemented and important objects abstractions used in this package.

Calculate Modules
-----------------

.. autoclass:: calculate.base::BaseAlgorithm

.. autoclass:: calculate.euclidean::Euclidean

.. autoclass:: calculate.dtw::DTW

.. autoclass:: calculate.rdp::RDP

.. autoclass:: calculate.lcss::LCSS

.. autoclass:: calculate.frechet::Frechet

.. autoclass:: calculate.hausdorff::Hausdorff

.. autoclass:: calculate.editdistance::EditDistance

.. autoclass:: calculate.manhattan::Manhattan

.. autoclass:: calculate.sad::SAD

Objects
-------

.. autoclass:: objects.cstructures::Point

.. autoclass:: objects.cstructures::Trajectory

.. autoclass:: objects.geojson::GeoJSON
